import _objectSpread from '@babel/runtime/helpers/esm/objectSpread2';
import _objectWithoutProperties from '@babel/runtime/helpers/esm/objectWithoutProperties';
import { useContext } from 'react';
import PropTypes from 'prop-types';
import { useBrand, getLabel, overrideReconciler } from '@westpac/core';
import { ButtonContext } from '@westpac/button';
import '@babel/runtime/helpers/defineProperty';
import { jsx } from '@emotion/react/jsx-runtime';

var _excluded$1 = ["state"];
(Badge === null || Badge === void 0 ? void 0 : Badge.defaultProps) || {};

// ==============================
// Component
// ==============================

var Badge$1 = function Badge(_ref) {
  _ref.state;
    var rest = _objectWithoutProperties(_ref, _excluded$1);
  return jsx("span", _objectSpread({}, rest));
};

// ==============================
// Styles
// ==============================

var badgeStyles = function badgeStyles(_, _ref3) {
  var look = _ref3.look,
    type = _ref3.type,
    btnContext = _ref3.btnContext;
  var _useBrand = useBrand(),
    COLORS = _useBrand.COLORS,
    TYPE = _useBrand.TYPE;
  var invert = btnContext && !((btnContext === null || btnContext === void 0 ? void 0 : btnContext.state.look) === 'faint' || btnContext !== null && btnContext !== void 0 && btnContext.state.soft);
  console.log(btnContext === null || btnContext === void 0 ? void 0 : btnContext.state.look, invert);
  return _objectSpread(_objectSpread({
    label: getLabel('badge'),
    display: 'inline-block',
    border: invert ? 'none' : '1px solid',
    borderRadius: type === 'pill' ? '0.75rem' : '0.125rem',
    fontSize: type === 'pill' ? '0.875rem' : '0.75rem',
    lineHeight: 1,
    minWidth: '0.625rem',
    // double check this
    padding: type === 'pill' ? '0.25rem 0.4375rem' : '0.1875rem 0.375rem 0.125rem',
    textAlign: 'center',
    verticalAlign: 'baseline',
    whiteSpace: 'nowrap',
    color: look === 'faint' ? COLORS.muted : invert ? COLORS[look] : COLORS.white,
    backgroundColor: invert || look === 'faint' ? COLORS.white : COLORS[look],
    borderColor: look === 'faint' ? COLORS.border : COLORS[look]
  }, type === 'pill' ? TYPE.bodyFont[700] : TYPE.bodyFont[400]), {}, {
    ':empty': {
      display: 'none'
    },
    '@media print': {
      color: COLORS.black,
      backgroundColor: COLORS.white,
      border: "1px solid ".concat(COLORS.black)
    }
  });
};

// ==============================
// Attributes
// ==============================

var badgeAttributes = function badgeAttributes() {
  return null;
};

// ==============================
// Exports
// ==============================

var defaultBadge = {
  component: Badge$1,
  styles: badgeStyles,
  attributes: badgeAttributes
};

var pkg = {
	name: "@westpac/badge",
	version: "2.3.0",
	description: "Small, coloured UI items used to highlight a number count",
	homepage: "https://gel.westpacgroup.com.au/design-system",
	repository: "https://github.com/WestpacGEL/GEL/tree/master/components/badge",
	license: "GPL-3.0+",
	author: "Westpac GEL Team <gel@westpac.com.au>",
	contributors: [
		{
			name: "Dominik Wilkowski",
			email: "Hi@Dominik-Wilkowski.com",
			url: "https://dominik-wilkowski.com"
		},
		{
			name: "Jonathan Stening",
			email: "info@jonathanstening.com",
			url: "http://jonathanstening.com"
		},
		{
			name: "Jeremy Ortiz",
			email: "jeremy@jeremyortiz.io",
			url: "https://www.jeremyortiz.io/"
		},
		{
			name: "Flore Laforge",
			email: "florelaforge@gmail.com",
			url: "http://florelaforge.com/"
		}
	],
	main: "dist/westpac-badge.cjs.js",
	module: "dist/westpac-badge.esm.js",
	scripts: {
		start: "PACKAGE_NAME=badge NODE_ENV=development webpack server --config ../../helpers/example/start.webpack.config.js",
		test: "exit 0 # start-server-and-test start http://localhost:8080 test:all",
		"test:all": "yarn test:integration",
		"test:dev": "start-server-and-test start http://localhost:8080 test:test-dev",
		"test:integration": "cypress run",
		"test:test-dev": "cypress open"
	},
	dependencies: {
		"@babel/runtime": "^7.14.8",
		"@westpac/button": "^3.0.0",
		"@westpac/core": "^3.2.1",
		"prop-types": "^15.7.2"
	},
	devDependencies: {
		"@emotion/react": "^11.10.6",
		"@westpac/body": "^2.2.1",
		"@westpac/grid": "^2.2.1",
		cypress: "^8.0.0",
		react: "^18.2.0",
		"start-server-and-test": "^1.12.6"
	},
	peerDependencies: {
		"@emotion/react": "^11.10.6",
		react: "^18.2.0"
	},
	blender: {
		recipe: "blender/recipe.js"
	},
	components: [
		{
			name: "Badge",
			src: "Badge.tsx"
		}
	]
};

var _excluded = ["value", "look", "type", "overrides"];
// ==============================
// Component
// ==============================

var Badge = function Badge(_ref) {
  var value = _ref.value,
    _ref$look = _ref.look,
    look = _ref$look === void 0 ? 'neutral' : _ref$look,
    _ref$type = _ref.type,
    type = _ref$type === void 0 ? 'default' : _ref$type,
    componentOverrides = _ref.overrides,
    rest = _objectWithoutProperties(_ref, _excluded);
  var _useBrand = useBrand(),
    tokenOverrides = _useBrand.OVERRIDES[pkg.name],
    brandOverrides = _useBrand[pkg.name];
  var defaultOverrides = {
    Badge: defaultBadge
  };
  var btnContext = useContext(ButtonContext);
  var state = _objectSpread({
    look: look,
    value: value,
    type: type,
    btnContext: btnContext,
    overrides: componentOverrides
  }, rest);
  var _overrideReconciler = overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
    _overrideReconciler$B = _overrideReconciler.Badge,
    Badge = _overrideReconciler$B.component,
    badgeStyles = _overrideReconciler$B.styles,
    badgeAttributes = _overrideReconciler$B.attributes;
  return jsx(Badge, _objectSpread(_objectSpread(_objectSpread({}, rest), {}, {
    state: state
  }, badgeAttributes(state)), {}, {
    css: badgeStyles(state),
    children: value
  }));
};
Badge.propTypes = {
  // ----------------------------- Warning --------------------------------
  // | These PropTypes are generated from the TypeScript type definitions |
  // |     To update them edit TypeScript types and run "yarn prop-types"  |
  // ----------------------------------------------------------------------
  /**
   * Badge look
   */
  look: PropTypes.oneOf(['danger', 'faint', 'hero', 'info', 'neutral', 'primary', 'success', 'warning']).isRequired,
  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Badge: PropTypes.shape({
      attributes: PropTypes.func,
      component: PropTypes.elementType,
      styles: PropTypes.func
    })
  }),
  /**
   * Badge type
   */
  type: PropTypes.oneOf(['default', 'pill']),
  /**
   * Badge text
   */
  value: PropTypes.string.isRequired
};

export { Badge };
